@@ -213,6 +213,8 @@ OAUTH2_TYPE_DECLARE_MEMBER_SET(http, call_ctx, ca_info, char *)
 OAUTH2_TYPE_DECLARE_MEMBER_SET(http, call_ctx, ssl_cert, char *)
 OAUTH2_TYPE_DECLARE_MEMBER_SET(http, call_ctx, ssl_key, char *)
 OAUTH2_TYPE_DECLARE_MEMBER_SET(http, call_ctx, timeout, int)
+OAUTH2_TYPE_DECLARE_MEMBER_SET(http, call_ctx, retries, int)
+OAUTH2_TYPE_DECLARE_MEMBER_SET(http, call_ctx, retry_interval, int)
 OAUTH2_TYPE_DECLARE_MEMBER_SET(http, call_ctx, ssl_verify, bool)
 OAUTH2_MEMBER_LIST_DECLARE_SET_UNSET_ADD_GET(http, call_ctx, cookie)
 OAUTH2_MEMBER_LIST_DECLARE_SET_UNSET_ADD_GET(http, call_ctx, hdr)
